@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import logging
 import os
 import time
 
@@ -24,6 +25,8 @@ from novaclient.openstack.common.apiclient import exceptions as novaexc
 from novaclient.v1_1 import client as novav11client
 from novaclient.v1_1.contrib import baremetal
 
+LOG = logging.getLogger(__name__)
+
 
 def register_nova_bm_node(service_host, node, client=None):
     if not service_host:
@@ -32,15 +35,26 @@ def register_nova_bm_node(service_host, node, client=None):
     # Nova now enforces the password to be 255 or less characters, and the
     # ssh key/password to use is set in configuration.
     if len(node["pm_password"]) <= 255:
+        LOG.debug('Setting pm_password for nova-bm, it is <=255 characters.')
         kwargs["pm_password"] = node["pm_password"]
+    else:
+        LOG.info('Ignoring pm_password for nova-bm, it is >255 characters.')
+    node_created = False
     for count in range(60):
+        LOG.debug('Registering %s node with nova-baremetal, try #%d.' %
+                  (node["pm_addr"], count))
         try:
             bm_node = client.baremetal.create(service_host, node["cpu"],
                                               node["memory"], node["disk"],
                                               node["mac"][0], **kwargs)
+            node_created = True
             break
         except (novaexc.ConnectionRefused, novaexc.ServiceUnavailable):
+            LOG.debug('Service not available, sleeping for 10 seconds.')
             time.sleep(10)
+    if not node_created:
+        LOG.debug('Service unavailable after 10 minutes, giving up.')
+        raise novaexc.ServiceUnavailable()
     for mac in node["mac"][1:]:
         client.baremetal.add_interface(bm_node, mac)
 
@@ -62,14 +76,22 @@ def register_ironic_node(service_host, node, client=None):
     else:
         raise Exception("Unknown pm_type: %s" % node["pm_type"])
 
+    node_created = False
     for count in range(60):
+        LOG.debug('Registering %s node with ironic, try #%d.' %
+                  (node["pm_addr"], count))
         try:
             ironic_node = client.node.create(driver=node["pm_type"],
                                              driver_info=driver_info,
                                              properties=properties)
+            node_created = True
             break
         except (ironicexp.ConnectionRefused, ironicexp.ServiceUnavailable):
+            LOG.debug('Service not available, sleeping for 10 seconds.')
             time.sleep(10)
+    if not node_created:
+        LOG.debug('Service unavailable after 10 minutes, giving up.')
+        raise ironicexp.ServiceUnavailable()
 
     for mac in node["mac"]:
         client.port.create(address=mac, node_uuid=ironic_node.uuid)
@@ -78,6 +100,7 @@ def register_ironic_node(service_host, node, client=None):
 
 
 def _get_nova_bm_client():
+    LOG.debug('Creating nova client.')
     baremetal_extension = Extension('baremetal', baremetal)
     return novav11client.Client(os.environ["OS_USERNAME"],
                                 os.environ["OS_PASSWORD"],
@@ -87,6 +110,7 @@ def _get_nova_bm_client():
 
 
 def _get_ironic_client():
+    LOG.debug('Creating ironic client.')
     kwargs = {'os_username': os.environ['OS_USERNAME'],
               'os_password': os.environ['OS_PASSWORD'],
               'os_auth_url': os.environ['OS_AUTH_URL'],
@@ -95,6 +119,7 @@ def _get_ironic_client():
 
 
 def _get_keystone_client():
+    LOG.debug('Creating keystone client.')
     kwargs = {'username': os.environ["OS_USERNAME"],
               'password': os.environ["OS_PASSWORD"],
               'tenant_name': os.environ["OS_TENANT_NAME"],
@@ -103,6 +128,7 @@ def _get_keystone_client():
 
 
 def register_all_nodes(service_host, nodes_list, client=None):
+    LOG.debug('Registering all nodes.')
     if using_ironic(keystone=None):
         if client is None:
             client = _get_ironic_client()
@@ -116,6 +142,7 @@ def register_all_nodes(service_host, nodes_list, client=None):
 
 
 def using_ironic(keystone=None):
+    LOG.debug('Checking for usage of ironic.')
     if keystone is None:
         keystone = _get_keystone_client()
     return 'ironic' in [service.name for service in keystone.services.list()]
